@@ -2,12 +2,12 @@ package AI::Genetic::Pro;
 
 use vars qw($VERSION);
 
-$VERSION = 1.001;
+$VERSION = 1.002;
 #---------------
 
 use warnings;
 use strict;
-use base 							qw( Class::Accessor::Fast );
+use base 							qw( Class::Accessor::Fast::XS );
 #-----------------------------------------------------------------------
 use Carp;
 use Clone 							qw( clone );
@@ -666,7 +666,7 @@ __END__
 
 =head1 NAME
 
-AI::Genetic::Pro - Efficient genetic algorithms for professional purpose.
+AI::Genetic::Pro - Efficient genetic algorithms for professional purpose with support for multiprocessing.
 
 =head1 SYNOPSIS
 
@@ -722,7 +722,7 @@ AI::Genetic::Pro - Efficient genetic algorithms for professional purpose.
 =head1 DESCRIPTION
 
 This module provides efficient implementation of a genetic algorithm for
-professional use. It was designed to operate as fast as possible
+professional use with support for multiprocessing. It was designed to operate as fast as possible
 even on very large populations and big individuals/chromosomes. C<AI::Genetic::Pro> 
 was inspired by C<AI::Genetic>, so it is in most cases compatible 
 (there are some changes). Additionally C<AI::Genetic::Pro> isn't a pure Perl solution, so it 
@@ -740,12 +740,12 @@ mind. This distribution was tested on Windows and Linux platforms
 (and should work on any other).
 
 Multicore support is available through Many-Core Engine (C<MCE>). 
-You can gain the most speed up for large populations or time/CPU consuming 
+You can gain the most speed up for big populations ora time/CPU consuming 
 fitness functions, however for small populations and/or simple fitness 
 function better choice will be single-process version.
 
-You can get even more speed up if you turn on use of native arrays 
-(C< -native => 1 >) instead of packing chromosomes into single scalar. 
+You can gat even more speed up if you turn on use of native arrays 
+(parameter: C<native>) instead of packing chromosomes into single scalar. 
 However you have to remember about expensive memory use in that case.
 
 =item Memory
